pySOT package
=============

Subpackages
-----------

.. toctree::

    pySOT.test

Submodules
----------

pySOT.ensemble_surrogate module
------------------------------

.. automodule:: pySOT.ensemble_surrogate
    :members:
    :undoc-members:
    :show-inheritance:

pySOT.experimental_design module
--------------------------------

.. automodule:: pySOT.experimental_design
    :members:
    :undoc-members:
    :show-inheritance:

pySOT.kriging_interpolant module
--------------------------------

.. automodule:: pySOT.kriging_interpolant
    :members:
    :undoc-members:
    :show-inheritance:

pySOT.mars_interpolant module
-----------------------------

.. automodule:: pySOT.mars_interpolant
    :members:
    :undoc-members:
    :show-inheritance:

pySOT.rbf_interpolant module
----------------------------

.. automodule:: pySOT.rbf_interpolant
    :members:
    :undoc-members:
    :show-inheritance:

pySOT.rs_capped module
----------------------

.. automodule:: pySOT.rs_capped
    :members:
    :undoc-members:
    :show-inheritance:

pySOT.search_procedure module
-----------------------------

.. automodule:: pySOT.search_procedure
    :members:
    :undoc-members:
    :show-inheritance:

pySOT.sot_sync_strategies module
---------------------

.. automodule:: pySOT.sot_sync_strategies
    :members:
    :undoc-members:
    :show-inheritance:

pySOT.test_problems module
--------------------------

.. automodule:: pySOT.test_problems
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pySOT
    :members:
    :undoc-members:
    :show-inheritance:
